@@ -277,7 +277,7 @@ class BlackRendererFont:
     def _drawPaintSkew(self, paint, canvas):
         transform = Transform()
         transform = transform.skew(
-            math.radians(paint.xSkewAngle), math.radians(paint.ySkewAngle)
+            -math.radians(paint.xSkewAngle), math.radians(paint.ySkewAngle)
         )
         self._applyTransform(transform, paint.Paint, canvas)
 
@@ -285,7 +285,7 @@ class BlackRendererFont:
         transform = Transform()
         transform = transform.translate(paint.centerX, paint.centerY)
         transform = transform.skew(
-            math.radians(paint.xSkewAngle), math.radians(paint.ySkewAngle)
+            -math.radians(paint.xSkewAngle), math.radians(paint.ySkewAngle)
         )
         transform = transform.translate(-paint.centerX, -paint.centerY)
         self._applyTransform(transform, paint.Paint, canvas)
@@ -370,10 +370,10 @@ class BlackRendererFont:
         self.currentPath = path
         self.currentTransform = Identity
         with canvas.savedState():
-            if currentTransform != Identity:
-                canvas.transform(currentTransform)
             if currentPath is not None:
                 canvas.clipPath(currentPath)
+            if currentTransform != Identity:
+                canvas.transform(currentTransform)
             yield
         self.currentPath = currentPath
         self.currentTransform = currentTransform
@@ -394,6 +394,7 @@ class BlackRendererFont:
 
     def _getGlyphBounds(self, glyphName):
         gid = self.ttFont.getGlyphID(glyphName)
+        assert gid is not None, glyphName
         x, y, w, h = self.hbFont.get_glyph_extents(gid)
         # convert from HB's x/y_bearing + extents to xMin, yMin, xMax, yMax
         y += h
